@@ -925,7 +925,6 @@ function expireDevice (nodes, dirs, minFreeSpaceG, nextCb) {
   }
   const query = {
     _source: ['num', 'name', 'first', 'size', 'node', 'indexFilename'],
-    from: '10',
     size: 500,
     query: {
       bool: {
@@ -953,7 +952,6 @@ function expireDevice (nodes, dirs, minFreeSpaceG, nextCb) {
     console.log('EXPIRE - device query', JSON.stringify(query, false, 2));
   }
 
-  // Keep at least 10 files
   Db.search('files', 'file', query, function (err, data) {
     if (err || data.error || !data.hits) {
       if (Config.debug > 0) {
@@ -965,7 +963,7 @@ function expireDevice (nodes, dirs, minFreeSpaceG, nextCb) {
     if (Config.debug === 1) {
       console.log('EXPIRE - device results hits:', data.hits.hits.length);
     } else if (Config.debug > 1) {
-      console.log('EXPIRE - device results', JSON.stringify(err, false, 2), JSON.stringify(data, false, 2));
+      console.log('EXPIRE - device results', data.hits.hits.length, JSON.stringify(err, false, 2), JSON.stringify(data, false, 2));
     }
 
     if (data.hits.total <= 10) {
@@ -973,6 +971,9 @@ function expireDevice (nodes, dirs, minFreeSpaceG, nextCb) {
       return nextCb();
     }
 
+    // Keep 10 most recent files by truncating array
+    data.hits.hits.length -= 10;
+
     async.forEachSeries(data.hits.hits, function (item, forNextCb) {
       const fields = item._source || item.fields;
 
@@ -988,7 +989,11 @@ function expireDevice (nodes, dirs, minFreeSpaceG, nextCb) {
       if (freeG < minFreeSpaceG) {
         console.log('Deleting', item);
         if (item.indexFilename) {
-          fs.unlink(item.indexFilename, () => {});
+          fs.unlink(item.indexFilename, (err) => {
+            if (err) {
+              console.log('EXPIRE - error deleting index file', item.indexFilename, err);
+            }
+          });
         }
         return Db.deleteFile(fields.node, item._id, fields.name, forNextCb);
       } else {
